/*
 * Jednoduche kresleni v Jave.
 * 
 * Jiri Skala, brezen 2008
 * 
 */
package simpleDrawing;

import java.awt.*;
import java.awt.event.*;
import javax.swing.*;
import javax.swing.event.*;

/**
 * Jednoduche kresleni v Jave.
 * 
 * @author Jiri Skala
 */
public class SimpleDrawing extends JFrame {

	/**
	 * Panely pro usporadani ovladacich prvku v okne.
	 */
	private JPanel contentPane, panelTools;
	
	/**
	 * Panel kam budeme kreslit.
	 */
	private PanelCanvas panelCanvas;
	
	/**
	 * Prepinaci policka pro tahani/mazani krizku.
	 */
	private JRadioButton radioDrag, radioDelete;
	
	/**
	 * Skupina prepinacich policek.
	 * Nutne pro spravnou funkci (vzdy jen jedno zaskrtnute).
	 */
	private ButtonGroup radioGroup;
	
	/**
	 * Napis.
	 */
	private JLabel labelNote;
	
	/**
	 * Tlacitko pro vytvoreni krizku.
	 */
	private JButton buttonCrosses;
	
	
	
	
	
	/**
	 * Zobrazi okno aplikace.
	 * 
	 * @param args Command line arguments.
	 */
	public static void main(String[] args) {
		new SimpleDrawing().setVisible(true);
	}

	/**
	 * Konstruktor hlavniho okna.
	 */
	public SimpleDrawing() {
		
		// nastavime vlastnosti okna
		this.setTitle("Trochu pokroil kreslen");
		this.setSize(800, 600);
		this.setLocationRelativeTo(null);
		this.setDefaultCloseOperation(JFrame.EXIT_ON_CLOSE);
		
		// poskladame GUI
		contentPane = new JPanel(new BorderLayout());
		this.setContentPane(contentPane);
		
		panelTools = new JPanel();
		panelTools.setLayout(new BoxLayout(panelTools, BoxLayout.PAGE_AXIS));
		panelTools.setPreferredSize(new Dimension(200, 200));
		
		radioDrag = new JRadioButton("Tahat kky", true);
		radioDelete = new JRadioButton("Mazat kky");
		radioDelete.addChangeListener(new RadioChangeListener());
		
		radioGroup = new ButtonGroup();
		radioGroup.add(radioDrag);
		radioGroup.add(radioDelete);
		
		labelNote = new JLabel("<html>Pi vytven/mazn muste klikat pesn "
				+ "(nepohybovat pi tom my). Pokud vm to vad, "
				+ "pesute obsluhu udlosti z mouseClicked do mouseReleased.</html>");
		
		buttonCrosses = new JButton("Vytvo kky");
		buttonCrosses.addActionListener(new ButtonActionListener());
		
		panelTools.add(radioDrag);
		panelTools.add(radioDelete);
		panelTools.add(labelNote);
		panelTools.add(buttonCrosses);
		
		panelCanvas = new PanelCanvas();
		
		contentPane.add(panelTools, BorderLayout.WEST);
		contentPane.add(panelCanvas, BorderLayout.CENTER);
	}
	
	
	
	
	
	/**
	 * Trida pro obsluhu udalosti prepinaciho policka.
	 * 
	 * @author Jiri Skala
	 */
	private class RadioChangeListener implements ChangeListener {

		/**
		 * Reakce na zmenu stavu policka.
		 */
		public void stateChanged(ChangeEvent e) {
			
			// nastavime prislusnou operaci
			panelCanvas.setClickDeletes(radioDelete.isSelected());
		}	
	}
	
	/**
	 * Trida pro obsluhu udalosti tlacitka.
	 * 
	 * @author Jiri Skala
	 */
	private class ButtonActionListener implements ActionListener {
		
		// uz byly krizky vytvoreny?
		private boolean crossesCreated = false;
		
		/**
		 * Reakce na stisk tlacitka.
		 */
		public void actionPerformed(ActionEvent e) {
			
			if ( ! crossesCreated) {
				// vytvorime krizky
				panelCanvas.createCrosses(20, 20);
				panelCanvas.repaint();
				crossesCreated = true;
			}
		}
	}
}
